summaryrefslogtreecommitdiffstats
path: root/src/gui/editors/notation/NoteCharacter.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/editors/notation/NoteCharacter.h')
-rw-r--r--src/gui/editors/notation/NoteCharacter.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/src/gui/editors/notation/NoteCharacter.h b/src/gui/editors/notation/NoteCharacter.h
index bc9359e..3b27e87 100644
--- a/src/gui/editors/notation/NoteCharacter.h
+++ b/src/gui/editors/notation/NoteCharacter.h
@@ -26,13 +26,13 @@
#ifndef _RG_NOTECHARACTER_H_
#define _RG_NOTECHARACTER_H_
-#include <qpixmap.h>
-#include <qpoint.h>
-#include <qpointarray.h>
+#include <tqpixmap.h>
+#include <tqpoint.h>
+#include <tqpointarray.h>
-class QPainter;
-class QCanvasPixmap;
+class TQPainter;
+class TQCanvasPixmap;
namespace Rosegarden
{
@@ -40,13 +40,13 @@ namespace Rosegarden
class NoteCharacterDrawRep : public QPointArray
{
public:
- NoteCharacterDrawRep(int size = 0) : QPointArray(size) { }
+ NoteCharacterDrawRep(int size = 0) : TQPointArray(size) { }
};
/**
* NoteCharacter knows how to draw a character from a font. It may be
* optimised for screen (using QPixmap underneath to produce
* low-resolution colour or greyscale glyphs) or printer (using some
* internal representation to draw in high-resolution monochrome on a
* print device). You can use screen characters on a printer and vice
@@ -67,20 +67,20 @@ public:
int getWidth() const;
int getHeight() const;
- QPoint getHotspot() const;
+ TQPoint getHotspot() const;
- QPixmap *getPixmap() const;
- QCanvasPixmap *getCanvasPixmap() const;
+ TQPixmap *getPixmap() const;
+ TQCanvasPixmap *getCanvasPixmap() const;
- void draw(QPainter *painter, int x, int y) const;
- void drawMask(QPainter *painter, int x, int y) const;
+ void draw(TQPainter *painter, int x, int y) const;
+ void drawMask(TQPainter *painter, int x, int y) const;
private:
friend class NoteFont;
- NoteCharacter(QPixmap pixmap, QPoint hotspot, NoteCharacterDrawRep *rep);
+ NoteCharacter(TQPixmap pixmap, TQPoint hotspot, NoteCharacterDrawRep *rep);
- QPoint m_hotspot;
- QPixmap *m_pixmap; // I own this
+ TQPoint m_hotspot;
+ TQPixmap *m_pixmap; // I own this
NoteCharacterDrawRep *m_rep; // I don't own this, it's a reference to a static in the NoteFont
};
@@ -40,13 +40,13 @@ namespace Rosegarden
/**
* NoteCharacter knows how to draw a character from a font. It may be
- * optimised for screen (using QPixmap underneath to produce
+ * optimised for screen (using TQPixmap underneath to produce
* low-resolution colour or greyscale glyphs) or printer (using some
* internal representation to draw in high-resolution monochrome on a